# -*- coding: utf-8 -*-

# Copyright (C) 2010-2011 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
#
# Python X2go is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Python X2go is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

"""\
X2goClientSettings class - managing x2goclient settings file (incl. LDAP-Support).

The L{X2goClientSettings} class one of Python X2go's a public API classes.
Use this class (indirectly by retrieving it from an L{X2goClient} instance)
in your Python X2go based applications to access the
»settings« configuration file of your X2go client application.

"""
__NAME__ = 'x2gosettings-pylib'

# modules
import os

# Python X2go modules
import x2go.log as log
from x2go.defaults import X2GO_SETTINGS_CONFIGFILES as _X2GO_SETTINGS_CONFIGFILES
from x2go.defaults import X2GO_CLIENTSETTINGS_DEFAULTS as _X2GO_CLIENTSETTINGS_DEFAULTS
import x2go.inifiles as inifiles


class X2goClientSettingsWINREG(inifiles.X2goIniFile):
    """\
    Configuration file based settings for X2goClient instances.

    """
    defaultValues = _X2GO_CLIENTSETTINGS_DEFAULTS

    def __init__(self, config_files=_X2GO_SETTINGS_CONFIGFILES, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
        """\
        Constructs an L{X2goClientSettings} instance. This is normally done by an L{X2goClient} instance.
        You can retrieve this L{X2goClientSettings} instance with the L{X2goClient.get_client_settings()} 
        method.

        On construction the L{X2goClientSettings} object is filled with values from the configuration files::

            /etc/x2goclient/settings
            ~/.x2goclient/settings

        The files are read in the specified order and config options of both files are merged. Options 
        set in the user configuration file (C{~/.x2goclient/settings}) override global options set in
        C{/etc/x2goclient/settings}.

        """
        raise X2goNotImplementedYetException('WINREG backend support is not implemented yet')
